@@ -4,7 +4,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)$RCSfile: srmv1_procreq.c,v $ $Revision: 3489 $ $Date: 2010-03-16 10:40:28 +0100 (Tue, 16 Mar 2010) $ CERN Jean-Philippe Baud";
+static char sccsid[] = "@(#)$RCSfile: srmv1_procreq.c,v $ $Revision: 3791 $ $Date: 2010-09-13 08:01:29 +0200 (Mon, 13 Sep 2010) $ CERN Jean-Philippe Baud";
 #endif /* not lint */
 
 #include <sys/types.h>
@@ -27,7 +27,7 @@ static char *f_stat[] = {"Ready", "Pending", "Pending", "Ready", "Running", "Don
 extern char localdomain[CA_MAXHOSTNAMELEN+1];
 extern int nb_supported_protocols;
 extern char **supported_protocols;
-char *Cencode_groups (int, gid_t *, char *);
+char *Cencode_groups (int, gid_t *, char *, size_t);
 static int na_key = -1;
 
 int ns5__put (struct soap *soap, struct ArrayOfstring *srcarray, struct ArrayOfstring *surlarray, struct ArrayOflong *sizearray, struct ArrayOfboolean *permarray, struct ArrayOfstring *protoarray, struct ns5__putResponse *rep)
@@ -104,7 +104,10 @@ int ns5__put (struct soap *soap, struct ArrayOfstring *srcarray, struct ArrayOfs
 	dpm_req.r_uid = uid;
 	dpm_req.r_gid = gid;
 	strcpy (dpm_req.client_dn, clientdn);
-	(void) Cencode_groups (nbgids, gids, dpm_req.groups);
+	if (! Cencode_groups (nbgids, gids, dpm_req.groups, sizeof(dpm_req.groups))) {
+		dpm_req.status = DPM_FAILED | EINVAL;
+		strcpy (dpm_req.errstring, "Too many FQANs in proxy");
+	}
 	strcpy (dpm_req.clienthost, clienthost);
 	dpm_req.r_type = 'P';
 
@@ -306,7 +309,10 @@ int ns5__get (struct soap *soap, struct ArrayOfstring *surlarray, struct ArrayOf
 	dpm_req.r_uid = uid;
 	dpm_req.r_gid = gid;
 	strcpy (dpm_req.client_dn, clientdn);
-	(void) Cencode_groups (nbgids, gids, dpm_req.groups);
+	if (! Cencode_groups (nbgids, gids, dpm_req.groups, sizeof(dpm_req.groups))) {
+		dpm_req.status = DPM_FAILED | EINVAL;
+		strcpy (dpm_req.errstring, "Too many FQANs in proxy");
+	}
 	strcpy (dpm_req.clienthost, clienthost);
 	dpm_req.r_type = 'G';
 
@@ -513,7 +519,10 @@ int ns5__copy (struct soap *soap, struct ArrayOfstring *from_surls, struct Array
 	dpm_req.r_uid = uid;
 	dpm_req.r_gid = gid;
 	strcpy (dpm_req.client_dn, clientdn);
-	(void) Cencode_groups (nbgids, gids, dpm_req.groups);
+	if (! Cencode_groups (nbgids, gids, dpm_req.groups, sizeof(dpm_req.groups))) {
+		dpm_req.status = DPM_FAILED | EINVAL;
+		strcpy (dpm_req.errstring, "Too many FQANs in proxy");
+	}
 	strcpy (dpm_req.clienthost, clienthost);
 	dpm_req.r_type = 'C';
 
